@@ -284,7 +284,7 @@ class RedisBool(RedisNumber):
     def deserialize_value(self, value, redis_root):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
-            check_types(value, int)
+            check_types(value, str)
             value = int(value)
         return value
 
@@ -301,7 +301,7 @@ class RedisDecimal(RedisNumber):
     def deserialize_value(self, value, redis_root):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
-            check_types(value, (int, float))
+            check_types(value, str)
             value = decimal.Decimal(value)
         return value
 
@@ -439,17 +439,11 @@ class RedisRoot:
                 registered_models_names = [model.__name__ for model in redis_root.registered_models]
                 redis_fields = django_fields_to_redis_fields(django_model, redis_root)
                 if django_model.__name__ in registered_models_names:
-                    existing_redis_model_index = redis_root.registered_models_names.index(django_model.__name__)
+                    existing_redis_model_index = registered_models_names.index(django_model.__name__)
                     existing_redis_model = redis_root.registered_models[existing_redis_model_index]
-                    new_redis_model = update_redis_model_from_redis_fields(existing_redis_model, redis_fields, redis_root)
+                    new_redis_model = update_redis_model_from_redis_fields(django_model, existing_redis_model, redis_fields, redis_root)
                 else:
-                    new_redis_model = create_redis_model_from_redis_fields(redis_fields, redis_root)
-
-                for model in redis_root.registered_models:
-                    print()
-                    print(model)
-                    print(model.__dict__)
-
+                    new_redis_model = create_redis_model_from_redis_fields(django_model, redis_fields, redis_root)
                 return new_redis_model
             
             def django_fields_to_redis_fields(django_model, redis_root):
@@ -465,9 +459,8 @@ class RedisRoot:
                         redis_fields[django_field_name] = redis_field
                 return redis_fields
 
-            def create_redis_model_from_redis_fields(redis_fields, redis_root):
+            def create_redis_model_from_redis_fields(django_model, redis_fields, redis_root):
                 new_redis_model = type(django_model.__name__, (RedisModel,), redis_fields)
-                print(new_redis_model, new_redis_model.__class__.__name__)
                 redis_root.register_models([new_redis_model])
                 return new_redis_model
 
@@ -544,8 +537,8 @@ class RedisRoot:
                             allowed_redis_params[redis_field_param_name] = value
                 return allowed_redis_params
 
-            def update_redis_model_from_redis_fields(existing_redis_model, redis_fields, redis_root):
-                new_redis_model = create_redis_model_from_redis_fields(redis_fields, redis_root)
+            def update_redis_model_from_redis_fields(django_model, existing_redis_model, redis_fields, redis_root):
+                new_redis_model = create_redis_model_from_redis_fields(django_model, redis_fields, redis_root)
                 new_registered_models = []
                 for redis_model in redis_root.registered_models:
                     if redis_model == existing_redis_model:
